@@ -33,7 +33,9 @@ import com.smartgwt.client.widgets.tile.*;
 import com.smartgwt.client.widgets.tile.events.*;
 import com.smartgwt.client.widgets.grid.*;
 import com.smartgwt.client.widgets.grid.events.*;
+import com.smartgwt.client.widgets.chart.*;
 import com.smartgwt.client.widgets.layout.*;
+import com.smartgwt.client.widgets.layout.events.*;
 import com.smartgwt.client.widgets.menu.*;
 import com.smartgwt.client.widgets.tab.*;
 import com.smartgwt.client.widgets.toolbar.*;
@@ -171,6 +173,7 @@ public class Window extends VLayout  implements com.smartgwt.client.widgets.even
      * Color of the Window body. Overrides the background color specified in the style.
      *
      * @param bodyColor bodyColor Default value is "#FFFFFF"
+     * @see com.smartgwt.client.widgets.Window#flash
      * @see com.smartgwt.client.docs.Appearance Appearance overview and related methods
      */
     public void setBodyColor(String bodyColor) {
@@ -182,6 +185,7 @@ public class Window extends VLayout  implements com.smartgwt.client.widgets.even
      *
      *
      * @return String
+     * @see com.smartgwt.client.widgets.Window#flash
      * @see com.smartgwt.client.docs.Appearance Appearance overview and related methods
      */
     public String getBodyColor()  {
@@ -214,6 +218,7 @@ public class Window extends VLayout  implements com.smartgwt.client.widgets.even
      * showing, the Window can't be drag-repositioned regardless of this setting.
      *
      * @param canDragReposition canDragReposition Default value is true
+     * @see com.smartgwt.client.widgets.Window#setShowHeader
      */
     public void setCanDragReposition(Boolean canDragReposition) {
         setAttribute("canDragReposition", canDragReposition, true);
@@ -225,6 +230,7 @@ public class Window extends VLayout  implements com.smartgwt.client.widgets.even
      *
      *
      * @return Boolean
+     * @see com.smartgwt.client.widgets.Window#getShowHeader
      */
     public Boolean getCanDragReposition()  {
         return getAttributeAsBoolean("canDragReposition");
@@ -235,6 +241,7 @@ public class Window extends VLayout  implements com.smartgwt.client.widgets.even
      * icon in the footer.
      *
      * @param canDragResize canDragResize Default value is false
+     * @see com.smartgwt.client.widgets.Window#setShowResizer
      */
     public void setCanDragResize(Boolean canDragResize) {
         setAttribute("canDragResize", canDragResize, true);
@@ -246,6 +253,7 @@ public class Window extends VLayout  implements com.smartgwt.client.widgets.even
      *
      *
      * @return Boolean
+     * @see com.smartgwt.client.widgets.Window#getShowResizer
      */
     public Boolean getCanDragResize()  {
         return getAttributeAsBoolean("canDragResize");
@@ -311,6 +319,7 @@ public class Window extends VLayout  implements com.smartgwt.client.widgets.even
      *
      * @param contentsType contentsType Default value is "page"
      * @throws IllegalStateException this property cannot be changed after the component has been created
+     * @see com.smartgwt.client.widgets.Window#setSrc
      * @see com.smartgwt.client.docs.Appearance Appearance overview and related methods
      */
     public void setContentsType(String contentsType)  throws IllegalStateException {
@@ -325,6 +334,7 @@ public class Window extends VLayout  implements com.smartgwt.client.widgets.even
      *
      *
      * @return String
+     * @see com.smartgwt.client.widgets.Window#getSrc
      * @see com.smartgwt.client.docs.Appearance Appearance overview and related methods
      */
     public String getContentsType()  {
@@ -363,6 +373,7 @@ public class Window extends VLayout  implements com.smartgwt.client.widgets.even
      * <P> If unset default behavior depends on whether a close / cancel button is visible for this item.
      *
      * @param dismissOnEscape dismissOnEscape Default value is null
+     * @see com.smartgwt.client.widgets.Window#shouldDismissOnEscape
      */
     public void setDismissOnEscape(Boolean dismissOnEscape) {
         setAttribute("dismissOnEscape", dismissOnEscape, true);
@@ -375,6 +386,7 @@ public class Window extends VLayout  implements com.smartgwt.client.widgets.even
      *
      *
      * @return Boolean
+     * @see com.smartgwt.client.widgets.Window#shouldDismissOnEscape
      */
     public Boolean getDismissOnEscape()  {
         return getAttributeAsBoolean("dismissOnEscape");
@@ -385,6 +397,7 @@ public class Window extends VLayout  implements com.smartgwt.client.widgets.even
      * <b>Note:</b> Applies only to modal windows.
      *
      * @param dismissOnOutsideClick dismissOnOutsideClick Default value is false
+     * @see com.smartgwt.client.widgets.Window#setIsModal
      */
     public void setDismissOnOutsideClick(Boolean dismissOnOutsideClick) {
         setAttribute("dismissOnOutsideClick", dismissOnOutsideClick, true);
@@ -396,6 +409,7 @@ public class Window extends VLayout  implements com.smartgwt.client.widgets.even
      *
      *
      * @return Boolean
+     * @see com.smartgwt.client.widgets.Window#getIsModal
      */
     public Boolean getDismissOnOutsideClick()  {
         return getAttributeAsBoolean("dismissOnOutsideClick");
@@ -473,6 +487,7 @@ public class Window extends VLayout  implements com.smartgwt.client.widgets.even
      * Highlight color for the Window body (shown when the body is flashed).
      *
      * @param hiliteBodyColor hiliteBodyColor Default value is "#EEEEEE"
+     * @see com.smartgwt.client.widgets.Window#flash
      * @see com.smartgwt.client.docs.Appearance Appearance overview and related methods
      */
     public void setHiliteBodyColor(String hiliteBodyColor) {
@@ -484,6 +499,7 @@ public class Window extends VLayout  implements com.smartgwt.client.widgets.even
      *
      *
      * @return String
+     * @see com.smartgwt.client.widgets.Window#flash
      * @see com.smartgwt.client.docs.Appearance Appearance overview and related methods
      */
     public String getHiliteBodyColor()  {
@@ -698,6 +714,7 @@ public class Window extends VLayout  implements com.smartgwt.client.widgets.even
      *
      * @param modalMaskOpacity modalMaskOpacity Default value is 50
      * @throws IllegalStateException this property cannot be changed after the component has been created
+     * @see com.smartgwt.client.widgets.Window#setModalMask
      * @see com.smartgwt.client.docs.Appearance Appearance overview and related methods
      */
     public void setModalMaskOpacity(int modalMaskOpacity)  throws IllegalStateException {
@@ -709,6 +726,7 @@ public class Window extends VLayout  implements com.smartgwt.client.widgets.even
      *
      *
      * @return int
+     * @see com.smartgwt.client.widgets.Window#getModalMask
      * @see com.smartgwt.client.docs.Appearance Appearance overview and related methods
      */
     public int getModalMaskOpacity()  {
@@ -720,6 +738,7 @@ public class Window extends VLayout  implements com.smartgwt.client.widgets.even
      *
      * @param modalMaskStyle modalMaskStyle Default value is "modalMask"
      * @throws IllegalStateException this property cannot be changed after the component has been created
+     * @see com.smartgwt.client.widgets.Window#setModalMask
      * @see com.smartgwt.client.docs.Appearance Appearance overview and related methods
      */
     public void setModalMaskStyle(String modalMaskStyle)  throws IllegalStateException {
@@ -731,6 +750,7 @@ public class Window extends VLayout  implements com.smartgwt.client.widgets.even
      *
      *
      * @return String
+     * @see com.smartgwt.client.widgets.Window#getModalMask
      * @see com.smartgwt.client.docs.Appearance Appearance overview and related methods
      */
     public String getModalMaskStyle()  {
@@ -948,6 +968,7 @@ public class Window extends VLayout  implements com.smartgwt.client.widgets.even
      *
      * @param showModalMask showModalMask Default value is null
      * @throws IllegalStateException this property cannot be changed after the component has been created
+     * @see com.smartgwt.client.widgets.Window#setModalMask
      * @see com.smartgwt.client.docs.Appearance Appearance overview and related methods
      */
     public void setShowModalMask(Boolean showModalMask)  throws IllegalStateException {
@@ -959,6 +980,7 @@ public class Window extends VLayout  implements com.smartgwt.client.widgets.even
      *
      *
      * @return Boolean
+     * @see com.smartgwt.client.widgets.Window#getModalMask
      * @see com.smartgwt.client.docs.Appearance Appearance overview and related methods
      */
     public Boolean getShowModalMask()  {
@@ -1040,6 +1062,7 @@ public class Window extends VLayout  implements com.smartgwt.client.widgets.even
      * Sets the URL of the contents to display in the body of the window, redrawing if necessary.
      *
      * @param src URL of new contents to be displayed in the window body. Default value is null
+     * @see com.smartgwt.client.widgets.Window#setContentsType
      * @see com.smartgwt.client.docs.Appearance Appearance overview and related methods
      */
     public void setSrc(String src) {
@@ -1054,6 +1077,7 @@ public class Window extends VLayout  implements com.smartgwt.client.widgets.even
      *
      *
      * @return String
+     * @see com.smartgwt.client.widgets.Window#getContentsType
      * @see com.smartgwt.client.docs.Appearance Appearance overview and related methods
      */
     public String getSrc()  {
@@ -1107,7 +1131,10 @@ public class Window extends VLayout  implements com.smartgwt.client.widgets.even
     // ********************* Methods ***********************
             
     /**
-     * Add a canvas to the layout, optionally at a specific position.
+     * Same as {@link com.smartgwt.client.widgets.layout.Layout#addMember Layout.addMember}.  Note that in order to add items
+     * to {@link com.smartgwt.client.widgets.Window#getBody body}, you use {@link com.smartgwt.client.widgets.Window#addItem
+     * Window.addItem} rather than <code>addMember</code>.  Adding a member to  a Window adds the member as a sibling to the
+     * header, body and other built-in Window subcomponents.
      * @param newMember the canvas object to be added to the layout
      */
     public native void addMember(Canvas newMember) /*-{
@@ -1116,10 +1143,14 @@ public class Window extends VLayout  implements com.smartgwt.client.widgets.even
     }-*/;
 
     /**
-     * Add a canvas to the layout, optionally at a specific position.
+     * Same as {@link com.smartgwt.client.widgets.layout.Layout#addMember Layout.addMember}.  Note that in order to add items
+     * to {@link com.smartgwt.client.widgets.Window#getBody body}, you use {@link com.smartgwt.client.widgets.Window#addItem
+     * Window.addItem} rather than <code>addMember</code>.  Adding a member to  a Window adds the member as a sibling to the
+     * header, body and other built-in Window subcomponents.
      * @param newMember the canvas object to be added to the layout
      * @param position the position in the layout to place newMember (starts with 0);                                  if omitted, it will be
      * added at the last position
+     * @see com.smartgwt.client.widgets.Window#addMembers
      */
     public native void addMember(Canvas newMember, int position) /*-{
         var self = this.@com.smartgwt.client.widgets.BaseWidget::getOrCreateJsObj()();
@@ -1253,7 +1284,7 @@ public class Window extends VLayout  implements com.smartgwt.client.widgets.even
     /**
      * Adds a widget to the window.
      *
-     * @param item the widget to be added
+     * @param widget the widget to be added
      */
     public void addItem(Widget widget) {
         if (widget instanceof Canvas) {
@@ -1266,7 +1297,7 @@ public class Window extends VLayout  implements com.smartgwt.client.widgets.even
     /**
      * Adds a widget to the window.
      *
-     * @param item the widget to be added
+     * @param component the widget to be added
      */
     public void addItem(Canvas component) {
         JavaScriptObject componentJS = component.getOrCreateJsObj();
@@ -1295,7 +1326,7 @@ public class Window extends VLayout  implements com.smartgwt.client.widgets.even
     /**
      * Removes a widget from the window.
      *
-     * @param item the widget to be removed
+     * @param component the widget to be removed
      */
     public native void removeItem(Canvas component) /*-{
         var container = this.@com.smartgwt.client.widgets.BaseWidget::getOrCreateJsObj()();
