@@ -15,11 +15,15 @@
  */
 package com.google.gwt.autobean.shared.impl;
 
-import com.google.gwt.core.client.JsonUtils;
 import com.google.gwt.autobean.client.impl.JsoSplittable;
 import com.google.gwt.autobean.shared.Splittable;
+import com.google.gwt.core.client.JavaScriptException;
+import com.google.gwt.core.client.JsDate;
+import com.google.gwt.core.client.JsonUtils;
 import com.google.gwt.user.server.rpc.impl.ServerSerializationStreamWriter;
 
+import java.util.Date;
+
 /**
  * This a super-source version with a client-only implementation.
  */
@@ -39,4 +43,17 @@ public class StringQuoter {
     }
     return toReturn;
   }
+
+  public static Date tryParseDate(String date) {
+    try {
+      return new Date(Long.parseLong(date));
+    } catch (NumberFormatException ignored) {
+    }
+    try {
+      JsDate js = JsDate.create(date);
+      return new Date((long) js.getTime());
+    } catch (JavaScriptException ignored) {
+    }
+    return null;
+  }
 }
