@@ -23,7 +23,7 @@ import com.google.gwt.event.shared.GwtEvent;
 import com.google.gwt.event.shared.HandlerRegistration;
 import com.google.gwt.safehtml.shared.SafeHtml;
 import com.google.gwt.safehtml.shared.SafeHtmlBuilder;
-import com.google.gwt.user.cellview.client.HasKeyboardSelectionPolicy.KeyboardSelectionPolicy;
+import com.google.gwt.user.cellview.client.LoadingStateChangeEvent.LoadingState;
 import com.google.gwt.view.client.CellPreviewEvent;
 import com.google.gwt.view.client.HasData;
 import com.google.gwt.view.client.HasKeyProvider;
@@ -82,16 +82,6 @@ class HasDataPresenter<T> implements HasData<T>, HasKeyProvider<T>,
     void setSelected(boolean selected) throws IllegalStateException;
   }
 
-  /**
-   * The loading state of the data.
-   */
-  static enum LoadingState {
-    LOADING, // Waiting for data to load.
-    PARTIALLY_LOADED, // Partial page data loaded.
-    LOADED, // All page data loaded.
-    EMPTY; // The data size is 0.
-  }
-
   /**
    * The view that this presenter presents.
    * 
@@ -474,6 +464,11 @@ class HasDataPresenter<T> implements HasData<T>, HasKeyProvider<T>,
     return view.addHandler(handler, CellPreviewEvent.getType());
   }
 
+  public HandlerRegistration addLoadingStateChangeHandler(
+      LoadingStateChangeEvent.Handler handler) {
+    return view.addHandler(handler, LoadingStateChangeEvent.TYPE);
+  }
+
   public HandlerRegistration addRangeChangeHandler(
       RangeChangeEvent.Handler handler) {
     return view.addHandler(handler, RangeChangeEvent.getType());
@@ -657,6 +652,16 @@ class HasDataPresenter<T> implements HasData<T>, HasKeyProvider<T>,
     return pendingState != null;
   }
 
+  /**
+   * Check whether or not the data set is empty. That is, the row count is
+   * exactly 0.
+   * 
+   * @return true if data set is empty
+   */
+  public boolean isEmpty() {
+    return isRowCountExact() && getRowCount() == 0;
+  }
+
   public boolean isRowCountExact() {
     return getCurrentState().isRowCountExact();
   }
@@ -1193,37 +1198,43 @@ class HasDataPresenter<T> implements HasData<T>, HasKeyProvider<T>,
      * after the user has interacted with the widget at least once. This
      * prevents values from being selected by default.
      */
-    if (KeyboardSelectionPolicy.BOUND_TO_SELECTION == keyboardSelectionPolicy
-        && selectionModel != null && pending.viewTouched) {
-      T oldValue = oldState.getSelectedValue();
-      Object oldKey = getRowValueKey(oldValue);
-      T newValue = rowDataCount > 0
-          ? pending.getRowDataValue(pending.getKeyboardSelectedRow()) : null;
-      Object newKey = getRowValueKey(newValue);
-      /*
-       * Do not deselect the old value unless we have a new value to select, or
-       * we will have a null selection event while we wait for asynchronous data
-       * to load.
-       */
-      if (newKey != null && !newKey.equals(oldKey)) {
-        // Check both values for selection before setting selection, or the
-        // selection model may resolve state early.
-        boolean oldValueWasSelected = (oldValue == null) ? false
-            : selectionModel.isSelected(oldValue);
-        boolean newValueWasSelected = (newValue == null) ? false
-            : selectionModel.isSelected(newValue);
+    try {
+      if (KeyboardSelectionPolicy.BOUND_TO_SELECTION == keyboardSelectionPolicy
+          && selectionModel != null && pending.viewTouched) {
+        T oldValue = oldState.getSelectedValue();
+        Object oldKey = getRowValueKey(oldValue);
+        T newValue = rowDataCount > 0
+            ? pending.getRowDataValue(pending.getKeyboardSelectedRow()) : null;
+        Object newKey = getRowValueKey(newValue);
+        /*
+         * Do not deselect the old value unless we have a new value to select,
+         * or we will have a null selection event while we wait for asynchronous
+         * data to load.
+         */
+        if (newKey != null && !newKey.equals(oldKey)) {
+          // Check both values for selection before setting selection, or the
+          // selection model may resolve state early.
+          boolean oldValueWasSelected = (oldValue == null) ? false
+              : selectionModel.isSelected(oldValue);
+          boolean newValueWasSelected = (newValue == null) ? false
+              : selectionModel.isSelected(newValue);
 
-        // Deselect the old value.
-        if (oldValueWasSelected) {
-          selectionModel.setSelected(oldValue, false);
-        }
+          // Deselect the old value.
+          if (oldValueWasSelected) {
+            selectionModel.setSelected(oldValue, false);
+          }
 
-        // Select the new value.
-        pending.selectedValue = newValue;
-        if (newValue != null && !newValueWasSelected) {
-          selectionModel.setSelected(newValue, true);
+          // Select the new value.
+          pending.selectedValue = newValue;
+          if (newValue != null && !newValueWasSelected) {
+            selectionModel.setSelected(newValue, true);
+          }
         }
       }
+    } catch (RuntimeException e) {
+      // Unlock the rendering loop if the user SelectionModel throw an error.
+      isResolvingState = false;
+      throw e;
     }
 
     // If the keyboard row changes, add it to the modified set.
@@ -1338,64 +1349,70 @@ class HasDataPresenter<T> implements HasData<T>, HasKeyProvider<T>,
     /*
      * Push changes to the view.
      */
-    if (redrawRequired) {
-      // Redraw the entire content.
-      SafeHtmlBuilder sb = new SafeHtmlBuilder();
-      view.render(sb, pending.rowData, pending.pageStart, selectionModel);
-      SafeHtml newContents = sb.toSafeHtml();
-      if (!newContents.equals(lastContents)) {
-        lastContents = newContents;
-        view.replaceAllChildren(pending.rowData, newContents,
-            pending.keyboardStealFocus);
-      }
-      view.resetFocus();
-    } else if (range0 != null) {
-      // Replace specific rows.
-      lastContents = null;
-
-      // Replace range0.
-      {
-        int absStart = range0.getStart();
-        int relStart = absStart - pageStart;
+    try {
+      if (redrawRequired) {
+        // Redraw the entire content.
         SafeHtmlBuilder sb = new SafeHtmlBuilder();
-        List<T> replaceValues = pending.rowData.subList(relStart, relStart
-            + range0.getLength());
-        view.render(sb, replaceValues, absStart, selectionModel);
-        view.replaceChildren(replaceValues, relStart, sb.toSafeHtml(),
-            pending.keyboardStealFocus);
-      }
+        view.render(sb, pending.rowData, pending.pageStart, selectionModel);
+        SafeHtml newContents = sb.toSafeHtml();
+        if (!newContents.equals(lastContents)) {
+          lastContents = newContents;
+          view.replaceAllChildren(pending.rowData, newContents,
+              pending.keyboardStealFocus);
+        }
+        view.resetFocus();
+      } else if (range0 != null) {
+        // Replace specific rows.
+        lastContents = null;
 
-      // Replace range1 if it exists.
-      if (range1 != null) {
-        int absStart = range1.getStart();
-        int relStart = absStart - pageStart;
-        SafeHtmlBuilder sb = new SafeHtmlBuilder();
-        List<T> replaceValues = pending.rowData.subList(relStart, relStart
-            + range1.getLength());
-        view.render(sb, replaceValues, absStart, selectionModel);
-        view.replaceChildren(replaceValues, relStart, sb.toSafeHtml(),
-            pending.keyboardStealFocus);
-      }
+        // Replace range0.
+        {
+          int absStart = range0.getStart();
+          int relStart = absStart - pageStart;
+          SafeHtmlBuilder sb = new SafeHtmlBuilder();
+          List<T> replaceValues = pending.rowData.subList(relStart, relStart
+              + range0.getLength());
+          view.render(sb, replaceValues, absStart, selectionModel);
+          view.replaceChildren(replaceValues, relStart, sb.toSafeHtml(),
+              pending.keyboardStealFocus);
+        }
 
-      view.resetFocus();
-    } else if (keyboardRowChanged) {
-      // Update the keyboard selected rows without redrawing.
-      // Deselect the old keyboard row.
-      int oldSelectedRow = oldState.getKeyboardSelectedRow();
-      if (oldSelectedRow >= 0 && oldSelectedRow < rowDataCount) {
-        view.setKeyboardSelected(oldSelectedRow, false, false);
-      }
+        // Replace range1 if it exists.
+        if (range1 != null) {
+          int absStart = range1.getStart();
+          int relStart = absStart - pageStart;
+          SafeHtmlBuilder sb = new SafeHtmlBuilder();
+          List<T> replaceValues = pending.rowData.subList(relStart, relStart
+              + range1.getLength());
+          view.render(sb, replaceValues, absStart, selectionModel);
+          view.replaceChildren(replaceValues, relStart, sb.toSafeHtml(),
+              pending.keyboardStealFocus);
+        }
 
-      // Select the new keyboard row.
-      int newSelectedRow = pending.getKeyboardSelectedRow();
-      if (newSelectedRow >= 0 && newSelectedRow < rowDataCount) {
-        view.setKeyboardSelected(newSelectedRow, true,
-            pending.keyboardStealFocus);
+        view.resetFocus();
+      } else if (keyboardRowChanged) {
+        // Update the keyboard selected rows without redrawing.
+        // Deselect the old keyboard row.
+        int oldSelectedRow = oldState.getKeyboardSelectedRow();
+        if (oldSelectedRow >= 0 && oldSelectedRow < rowDataCount) {
+          view.setKeyboardSelected(oldSelectedRow, false, false);
+        }
+
+        // Select the new keyboard row.
+        int newSelectedRow = pending.getKeyboardSelectedRow();
+        if (newSelectedRow >= 0 && newSelectedRow < rowDataCount) {
+          view.setKeyboardSelected(newSelectedRow, true,
+              pending.keyboardStealFocus);
+        }
       }
+    } finally {
+      /*
+       * We are done resolving state, so unlock the rendering loop. We unlock
+       * the loop even if user rendering code throws an error to avoid throwing
+       * an additional, misleading IllegalStateException.
+       */
+      isResolvingState = false;
     }
-
-    // We are done resolving state.
-    isResolvingState = false;
   }
 
   /**
@@ -1500,9 +1517,7 @@ class HasDataPresenter<T> implements HasData<T>, HasKeyProvider<T>,
   private void updateLoadingState() {
     int cacheSize = getVisibleItemCount();
     int curPageSize = isRowCountExact() ? getCurrentPageSize() : getPageSize();
-    if (getRowCount() == 0 && isRowCountExact()) {
-      view.setLoadingState(LoadingState.EMPTY);
-    } else if (cacheSize >= curPageSize) {
+    if (cacheSize >= curPageSize) {
       view.setLoadingState(LoadingState.LOADED);
     } else if (cacheSize == 0) {
       view.setLoadingState(LoadingState.LOADING);
