@@ -1,6 +1,6 @@
 /*
  * Isomorphic SmartClient
- * Version 8.0 (2010-05-18)
+ * Version SC_SNAPSHOT-2010-12-31 (2010-12-31)
  * Copyright(c) 1998 and beyond Isomorphic Software, Inc. All rights reserved.
  * "SmartClient" is a trademark of Isomorphic Software, Inc.
  *
@@ -452,8 +452,8 @@ _getPositionedChildrenRight : function (element) {
 
 getElementRect : function (element) {
     var body = this.getDocumentBody(),
-        left = this._getLeftOffsetFromElement(element, body), 
-        top = this._getTopOffsetFromElement(element, body);
+        left = this.getLeftOffset(element, body), 
+        top = this.getTopOffset(element, body);
 
     var width = 0, height = 0;
     if (element.style && element.style.overflow == "visible") {
@@ -680,6 +680,10 @@ getOffsetLeft : function (element) {
     // IE and Moz both return somewhat unreliable values for element.offsetLeft by default.
     // Paper over these bugs and differences.
     var left = element.offsetLeft;
+    
+    if (isc.Browser.isIE && isc.Page.isRTL() && left < 0) {
+        left = -left;
+    }
     // --- caching code:
     // If we've already calculated a value (based on a reported offsetLeft value), and
     // the reported value has not changed, return the previously calculated value.
@@ -966,21 +970,21 @@ getOffsetTop : function (element) {
 
 },
 
-// _getLeftOffsetFromElement(element, targetElement, rtl)
+// getLeftOffset(element, targetElement, rtl)
 //
 // DOM Only method to return the absolute (offset) position for some element within some other 
 // DOM parent element.  We will return this value from the outside of any border / margin on
 // the child to the inside of the ancestor element.
 //
 
-_getLeftOffsetFromElement : function (element, targetElement, rtl) {
-    return this._getOffsetFromElement(isc.Canvas.LEFT, element, targetElement, rtl);
+getLeftOffset : function (element, targetElement, rtl, canvasArgs) {
+    return this.getOffset(isc.Canvas.LEFT, element, targetElement, rtl, canvasArgs);
 },
 
 // Return the absolute position of an element within a DOM parent element.
 // If no target parent element is passed, we return page level position.
-_getTopOffsetFromElement : function (element, targetElement) {
-    return this._getOffsetFromElement(isc.Canvas.TOP, element, targetElement);
+getTopOffset : function (element, targetElement, canvasArgs) {
+    return this.getOffset(isc.Canvas.TOP, element, targetElement, null, canvasArgs);
 },
 
 
@@ -989,8 +993,43 @@ _$borderTopWidth : isc.Browser.isMoz ? "border-top-width" : "borderTopWidth",
 _$marginLeft : isc.Browser.isMoz ? "margin-left" : "marginLeft",
 _$marginTop : isc.Browser.isMoz ? "margin-top" : "marginTop",
 _$none:"none",
-_getOffsetFromElement : function (dir, element, targetElement, rtl) {
+
+
+cacheCount:0,
+uncachedCount:0,
+_$leftCoords : "_$leftCoords",
+_$topCoords : "_$topCoords",
+
+// cacheOffestCoordinates: If set we will cache calculated offsets between SmartClient
+// ancestor/descendent components.
+// This improves performance on repeated lookups during (EG) drag/drop, etc
+
+cacheOffsetCoords:true,
+getOffset : function (dir, sourceElement, origTargetElement, rtl, canvasArgs) {
+    var sourceIsCanvas = canvasArgs || isc.isA.Canvas(sourceElement),
+        targetIsCanvas = canvasArgs || origTargetElement == null || isc.isA.Canvas(origTargetElement);
+
+    var cacheCoords = sourceIsCanvas && targetIsCanvas && this.cacheOffsetCoords && 
+                        (sourceElement.cacheOffsetCoords != false);
+    var coordCacheName = (dir == isc.Canvas.LEFT) ? this._$leftCoords : this._$topCoords;
+    if (cacheCoords && sourceElement[coordCacheName] != null) {
+        var cachedCoord = sourceElement[coordCacheName][origTargetElement ? origTargetElement.ID : this._$none];
+        if (cachedCoord != null) {
+            this.cacheCount++;
+            return cachedCoord;
+        }
+    }
+    this.uncachedCount++;
+
+    var element = sourceIsCanvas ? sourceElement.getClipHandle() : sourceElement;
+    var targetElement;
+
+    // if we're not passed an element, determine the offset from the top level HTML element.
+    if (origTargetElement == null) targetElement = this.getDocumentBody();
     
+    else if (targetIsCanvas) targetElement = origTargetElement.getHandle();
+    else targetElement = origTargetElement;
+
     //!DONTCOMBINE
     //>DEBUG
     if (targetElement == null || element == null) {
@@ -1018,7 +1057,6 @@ _getOffsetFromElement : function (dir, element, targetElement, rtl) {
         isLeft = (dir == isc.Canvas.LEFT),
         borderWidthProp = (isLeft ? this._$borderLeftWidth : this._$borderTopWidth),
         marginProp = (isLeft ? this._$marginLeft : this._$marginTop);
-  
 
     if (!isLeft) rtl = false;
     else if (rtl == null) rtl = (isc.Page.getTextDirection() == isc.Canvas.RTL);
@@ -1032,8 +1070,8 @@ _getOffsetFromElement : function (dir, element, targetElement, rtl) {
         // Add the currentNode's offsetLeft - left w.r.t. its offsetParent
         var subOffset = (isLeft ? this.ns.Element.getOffsetLeft(currentNode) :
                             this.ns.Element.getOffsetTop(currentNode));
-        offset += subOffset;                            
-
+        offset += subOffset;
+    
         // The offsetLeft/top value is relative to the content of the parent's element - so if
         // the parent is scrolled, and we want the floating position of this element within
         // it's parent we have to deduct the scrollLeft of the parent to page coordinate 
@@ -1118,6 +1156,12 @@ _getOffsetFromElement : function (dir, element, targetElement, rtl) {
         offset -= (isLeft ? this.ns.Element.getOffsetLeft(targetElement) :
                             this.ns.Element.getOffsetTop(targetElement));                  
     }
+
+    if (cacheCoords) {
+        var coordCache = sourceElement[coordCacheName] = sourceElement[coordCacheName] || {};
+        coordCache[origTargetElement ? origTargetElement.ID : this._$none] = offset;
+    }
+
     //this.logWarn("iterations: " + iterations);
     return offset;
 },
@@ -1209,25 +1253,43 @@ _deriveStyleProperties : function (className, mask) {
     if (!this._cellStyleTester) {
         
         this.createAbsoluteElement(
-            "<TABLE CELLPADDING=81 STYLE='position:absolute;left:0px;top:-300px;'><TR><TD " +
+            "<TABLE CELLPADDING=81 STYLE='position:absolute;left:0px;top:-2000px;'><TR><TD " +
             
             //(isc.Browser.isSafari ? "style='position:absolute;left:0px;top:0px;' " : "") +
             (isc.Browser.isIE8Strict ? 
             " ID=isc_cellStyleTester STYLE='border:0px;margin:0px'><DIV ID=isc_cellInnerStyleTester>" +
-                isc.Canvas.blankImgHTML(30,30) + "</DIV></TD></TR></TABLE>"                
+                isc.Canvas.blankImgHTML(30,30) + "</DIV></TD>"                
             :
-            " ID=isc_cellStyleTester>&nbsp;</TD></TR></TABLE>") 
+            " ID=isc_cellStyleTester>&nbsp;</TD>"
+            + "<TD ID=isc_cellNoStyleTester>&nbsp;</TD></TR></TABLE>"
+            ) 
         );
         this._cellStyleTester = isc.Element.get("isc_cellStyleTester");
         if (isc.Browser.isIE8Strict) {
             this._cellInnerStyleTester = isc.Element.get("isc_cellInnerStyleTester");
         }
-        this._$81px = "81px";                                 
+        // we set the table cellPadding to 81px - this will then be reported back
+        // if the padding on the style was unset (allows us to differentiate between
+        // null and explicit zero)
+        
+        this._$81px = "81px";
+        if (isc.Browser.isSafari || isc.Browser.isChrome) {
+            var noStyleElement = isc.Element.get("isc_cellNoStyleTester");
+            var paddingLeft = ["paddingLeft"];
+            var reported81 = this.getComputedStyle(noStyleElement, paddingLeft).paddingLeft;
+            if (reported81 != this._$81px) {
+                this.logDebug("Browser natively misreporting cell-padding (81px reported as:"
+                        + reported81 + "). This behavior is known to occur when the view is " +
+                        "zoomed in certain browsers but is worked around by SmartClient and " +
+                        "should have no visible effect on the application.", "sizing");
+                this._$81px = reported81;
+            }
+        }
         this._$16384px = "-16384px";       
 
         if (requiresDivTester) {
             this.createAbsoluteElement(
-                "<DIV ID=isc_styleTester STYLE='position:absolute;left:0px;top:-100px;'>&nbsp;</DIV>"
+                "<DIV ID=isc_styleTester STYLE='position:absolute;left:0px;top:-2000px;'>&nbsp;</DIV>"
             );
             this._styleTester = isc.Element.get("isc_styleTester");
             this._marginMask = ["marginLeft", "marginTop", "marginRight", "marginBottom"];
@@ -1482,6 +1544,11 @@ getStyleDeclaration : function (className, checkMultiples) {
             // @import css tags result in entries with no 'selectorText' property.            
             if (selectorText == null) continue;
 
+            
+            if (isc.Browser.isSafari && isc.Browser.safariVersion >= 312) {
+                selectorText = selectorText.toLowerCase()
+            }
+
             if (isc.Browser.isMoz) {
                 var selectorTextArray = selectorText.split(commaSpace);
                 
@@ -1971,6 +2038,10 @@ _getHBorderPad : function (className) {
 
 getNativeScrollbarSize : function () {
     if (isc.Element._nativeScrollbarSize == null) {
+        if (isc.Browser.isMobileWebkit) {
+            // native scrollbars don't exist in iPhone
+            return (isc.Element._nativeScrollbarSize = 16);
+        }
         var elementHTML = "<div id=isc_ScrollbarTest " 
                             + "style='position:absolute;top:-100px;border:0px;padding:0px;margin:0px;height:100px;width:100px;overflow:scroll;'>"
                             + isc.nbsp // XHTML
@@ -1985,8 +2056,26 @@ getNativeScrollbarSize : function () {
     }
     
     return isc.Element._nativeScrollbarSize;
+},
+
+// ---------------------------------------------------------------------------------------
+
+vendorCSSPrefix : (isc.Browser.isMoz ? "-moz-" :
+                   isc.Browser.isSafari ? "-webkit-" :
+                   isc.Browser.isOpera ? "-o-" :
+                   ""),
+// Return CSS to transform by degrees around an origin
+
+getRotationCSS : function (degrees, origin) {
+    var prefix = this.vendorCSSPrefix;
+    var text = prefix + "transform: rotate(" + degrees + "deg);";   
+    if (origin != null) {   
+        text += (prefix + "transform-origin: " + origin + ";");
+    }  
+    return text;
 }
 
+
 });
 
 isc.Element._ElementInit = function () {
