@@ -56,7 +56,20 @@ with (theWindow) {
         showCustomScrollbars:true,
         scrollbarSize:16,
         cornerSize:16
-    })
+    });
+
+    if(isc.Browser.isIE && isc.Browser.version >= 7) {
+        isc.Canvas.setAllowExternalFilters(false);
+        isc.Canvas.setNeverUseFilters(true);
+        if(isc.Window) {
+          isc.Window.addProperties({
+                modalMaskOpacity:null,
+                modalMaskStyle:"normal"
+            });
+            isc.Window.changeDefaults("modalMaskDefaults", { src : "[SKIN]opacity.png" });
+        }
+    }
+
     isc.ScrollThumb.addProperties({
         capSize:6,
         vSrc:"[SKIN]vthumb.png",
@@ -620,7 +633,7 @@ with (theWindow) {
         isc.DateItem.addProperties({
             pickerIconWidth:16,
             pickerIconHeight:16,
-            pickerIconSrc:"[SKIN]/controls/date_control.png"
+            pickerIconSrc:"[SKIN]/controls/date_control.gif"
         })
     }
     if (isc.SpinnerItem) {
