@@ -33,7 +33,9 @@ import com.smartgwt.client.widgets.tile.*;
 import com.smartgwt.client.widgets.tile.events.*;
 import com.smartgwt.client.widgets.grid.*;
 import com.smartgwt.client.widgets.grid.events.*;
+import com.smartgwt.client.widgets.chart.*;
 import com.smartgwt.client.widgets.layout.*;
+import com.smartgwt.client.widgets.layout.events.*;
 import com.smartgwt.client.widgets.menu.*;
 import com.smartgwt.client.widgets.tab.*;
 import com.smartgwt.client.widgets.toolbar.*;
@@ -62,7 +64,7 @@ import com.google.gwt.event.shared.HasHandlers;
  * <pre>&#010 &lt;TabSet&gt;&#010    &lt;tabs&gt;&#010        &lt;Tab title="tab1" pane="pane1"/&gt;&#010        &lt;Tab
  * title="tab2"/&gt;&#010    &lt;/tabs&gt;&#010 &lt;/TabSet&gt;&#010 </pre>
  */
-public class Tab extends RefDataClass {
+public class Tab extends RefDataClass  implements com.smartgwt.client.widgets.tab.events.HasTabDeselectedHandlers, com.smartgwt.client.widgets.tab.events.HasTabSelectedHandlers {
 
     public static Tab getOrCreateRef(JavaScriptObject jsObj) {
         if(jsObj == null) return null;
@@ -104,6 +106,7 @@ public class Tab extends RefDataClass {
      * canCloseTabs}
      *
      * @param canClose canClose Default value is null
+     * @see com.smartgwt.client.widgets.tab.TabSet#closeClick
      * @see <a href="http://www.smartclient.com/smartgwt/showcase/#layout_tabs_closeable" target="examples">Closeable Tabs Example</a>
      */
     public void setCanClose(Boolean canClose) {
@@ -119,12 +122,36 @@ public class Tab extends RefDataClass {
      *
      *
      * @return Boolean
+     * @see com.smartgwt.client.widgets.tab.TabSet#closeClick
      * @see <a href="http://www.smartclient.com/smartgwt/showcase/#layout_tabs_closeable" target="examples">Closeable Tabs Example</a>
      */
     public Boolean getCanClose()  {
         return getAttributeAsBoolean("canClose");
     }
 
+    /**
+     * If specified, overrides the {@link com.smartgwt.client.widgets.tab.TabSet#getCanEditTabTitles canEditTabTitles} setting,
+     * for this one tab only.
+     *
+     * @param canEditTitle canEditTitle Default value is null
+     * @see com.smartgwt.client.widgets.tab.TabSet#setCanEditTabTitles
+     */
+    public void setCanEditTitle(Boolean canEditTitle) {
+        setAttribute("canEditTitle", canEditTitle);
+    }
+
+    /**
+     * If specified, overrides the {@link com.smartgwt.client.widgets.tab.TabSet#getCanEditTabTitles canEditTabTitles} setting,
+     * for this one tab only.
+     *
+     *
+     * @return Boolean
+     * @see com.smartgwt.client.widgets.tab.TabSet#getCanEditTabTitles
+     */
+    public Boolean getCanEditTitle()  {
+        return getAttributeAsBoolean("canEditTitle");
+    }
+
     /**
      * Custom src for the close icon for this tab to display if it is closeable. See {@link
      * com.smartgwt.client.widgets.tab.Tab#getCanClose canClose} and {@link
@@ -148,6 +175,92 @@ public class Tab extends RefDataClass {
         return getAttributeAsString("closeIcon");
     }
 
+    /**
+     * Size of the {@link com.smartgwt.client.widgets.tab.Tab#getCloseIcon closeIcon} for this tab. If unspecified the icon
+     * will be sized according to {@link com.smartgwt.client.widgets.tab.TabSet#getCloseTabIconSize closeTabIconSize}
+     *
+     * @param closeIconSize closeIconSize Default value is null
+     */
+    public void setCloseIconSize(Integer closeIconSize) {
+        setAttribute("closeIconSize", closeIconSize);
+    }
+
+    /**
+     * Size of the {@link com.smartgwt.client.widgets.tab.Tab#getCloseIcon closeIcon} for this tab. If unspecified the icon
+     * will be sized according to {@link com.smartgwt.client.widgets.tab.TabSet#getCloseTabIconSize closeTabIconSize}
+     *
+     *
+     * @return Integer
+     */
+    public Integer getCloseIconSize()  {
+        return getAttributeAsInt("closeIconSize");
+    }
+
+    /**
+     * If {@link com.smartgwt.client.widgets.tab.Tab#getIcon icon} is specified, this property may be used to specify a size
+     * for the icon
+     *
+     * @param iconHeight iconHeight Default value is null
+     */
+    public void setIconHeight(Integer iconHeight) {
+        setAttribute("iconHeight", iconHeight);
+    }
+
+    /**
+     * If {@link com.smartgwt.client.widgets.tab.Tab#getIcon icon} is specified, this property may be used to specify a size
+     * for the icon
+     *
+     *
+     * @return Integer
+     */
+    public Integer getIconHeight()  {
+        return getAttributeAsInt("iconHeight");
+    }
+
+    /**
+     * If {@link com.smartgwt.client.widgets.tab.Tab#getIcon icon} is specified, this property may be used to specify a size
+     * for the icon. Per side sizing may be specified instead via {@link com.smartgwt.client.widgets.tab.Tab#getIconWidth
+     * iconWidth} and {@link com.smartgwt.client.widgets.tab.Tab#getIconHeight iconHeight}.
+     *
+     * @param iconSize iconSize Default value is null
+     */
+    public void setIconSize(Integer iconSize) {
+        setAttribute("iconSize", iconSize);
+    }
+
+    /**
+     * If {@link com.smartgwt.client.widgets.tab.Tab#getIcon icon} is specified, this property may be used to specify a size
+     * for the icon. Per side sizing may be specified instead via {@link com.smartgwt.client.widgets.tab.Tab#getIconWidth
+     * iconWidth} and {@link com.smartgwt.client.widgets.tab.Tab#getIconHeight iconHeight}.
+     *
+     *
+     * @return Integer
+     */
+    public Integer getIconSize()  {
+        return getAttributeAsInt("iconSize");
+    }
+
+    /**
+     * If {@link com.smartgwt.client.widgets.tab.Tab#getIcon icon} is specified, this property may be used to specify a size
+     * for the icon
+     *
+     * @param iconWidth iconWidth Default value is null
+     */
+    public void setIconWidth(Integer iconWidth) {
+        setAttribute("iconWidth", iconWidth);
+    }
+
+    /**
+     * If {@link com.smartgwt.client.widgets.tab.Tab#getIcon icon} is specified, this property may be used to specify a size
+     * for the icon
+     *
+     *
+     * @return Integer
+     */
+    public Integer getIconWidth()  {
+        return getAttributeAsInt("iconWidth");
+    }
+
     /**
      * Optional ID for the tab, which can later be used to reference the tab. APIs requiring a reference to a tab will accept
      * the tabs ID  [including  {@link com.smartgwt.client.widgets.tab.TabSet#selectTab TabSet.selectTab}, {@link
@@ -185,6 +298,8 @@ public class Tab extends RefDataClass {
      * com.smartgwt.client.widgets.tab.Tab#getTitle title} will be used instead
      *
      * @param pickerTitle pickerTitle Default value is null
+     * @see com.smartgwt.client.widgets.tab.TabSet#setShowTabPicker
+     * @see com.smartgwt.client.widgets.tab.Tab#setTitle
      */
     public void setPickerTitle(String pickerTitle) {
         setAttribute("pickerTitle", pickerTitle);
@@ -197,11 +312,32 @@ public class Tab extends RefDataClass {
      *
      *
      * @return String
+     * @see com.smartgwt.client.widgets.tab.TabSet#getShowTabPicker
+     * @see com.smartgwt.client.widgets.tab.Tab#getTitle
      */
     public String getPickerTitle()  {
         return getAttributeAsString("pickerTitle");
     }
 
+    /**
+     * Specifies the prompt to be displayed when the mouse hovers over the tab.
+     *
+     * @param prompt prompt Default value is null
+     */
+    public void setPrompt(String prompt) {
+        setAttribute("prompt", prompt);
+    }
+
+    /**
+     * Specifies the prompt to be displayed when the mouse hovers over the tab.
+     *
+     *
+     * @return String
+     */
+    public String getPrompt()  {
+        return getAttributeAsString("prompt");
+    }
+
     /**
      * You can specify an explicit width for the tab using this property.  Note that tabs automatically size to make room for
      * the full title, but if you want to e.g. specify a uniform width for all tabs in a TabSet, this property enables you to
@@ -226,6 +362,58 @@ public class Tab extends RefDataClass {
     }
 
     // ********************* Methods ***********************
+    /**
+     * Add a tabDeselected handler.
+     * <p>
+     * Optional handler to fire when a tab is deselected. Returning false will cancel the new selection, leaving this tab
+     * selected. As with {@link com.smartgwt.client.widgets.tab.TabSet#addTabSelectedHandler TabSet.tabSelected} this method
+     * only fires when the tabset is drawn.
+     *
+     * @param handler the tabDeselected handler
+     * @return {@link HandlerRegistration} used to remove this handler
+     */
+    public HandlerRegistration addTabDeselectedHandler(com.smartgwt.client.widgets.tab.events.TabDeselectedHandler handler) {
+        if(getHandlerCount(com.smartgwt.client.widgets.tab.events.TabDeselectedEvent.getType()) == 0) setupTabDeselectedEvent();
+        return doAddHandler(handler, com.smartgwt.client.widgets.tab.events.TabDeselectedEvent.getType());
+    }
+
+    private native void setupTabDeselectedEvent() /*-{
+        var obj = null;
+            obj = this.@com.smartgwt.client.core.DataClass::getJsObj()();
+            var selfJ = this;
+            obj.tabDeselected = $debox($entry(function(){
+                var param = {"tabSet" : arguments[0], "tabNum" : arguments[1], "tabPane" : arguments[2], "ID" : arguments[3], "tab" : arguments[4], "newTab" : arguments[5]};
+                var event = @com.smartgwt.client.widgets.tab.events.TabDeselectedEvent::new(Lcom/google/gwt/core/client/JavaScriptObject;)(param);
+                selfJ.@com.smartgwt.client.core.DataClass::fireEvent(Lcom/google/gwt/event/shared/GwtEvent;)(event);
+                var ret = event.@com.smartgwt.client.event.Cancellable::isCancelled()();
+                return !ret;
+            }));
+   }-*/;
+    /**
+     * Add a tabSelected handler.
+     * <p>
+     * Optional handler to fire when a tab is selected. As with {@link
+     * com.smartgwt.client.widgets.tab.TabSet#addTabSelectedHandler TabSet.tabSelected} this method only fires when the tabset
+     * is drawn.
+     *
+     * @param handler the tabSelected handler
+     * @return {@link HandlerRegistration} used to remove this handler
+     */
+    public HandlerRegistration addTabSelectedHandler(com.smartgwt.client.widgets.tab.events.TabSelectedHandler handler) {
+        if(getHandlerCount(com.smartgwt.client.widgets.tab.events.TabSelectedEvent.getType()) == 0) setupTabSelectedEvent();
+        return doAddHandler(handler, com.smartgwt.client.widgets.tab.events.TabSelectedEvent.getType());
+    }
+
+    private native void setupTabSelectedEvent() /*-{
+        var obj = null;
+            obj = this.@com.smartgwt.client.core.DataClass::getJsObj()();
+            var selfJ = this;
+            obj.tabSelected = $entry(function(){
+                var param = {"tabSet" : arguments[0], "tabNum" : arguments[1], "tabPane" : arguments[2], "ID" : arguments[3], "tab" : arguments[4]};
+                var event = @com.smartgwt.client.widgets.tab.events.TabSelectedEvent::new(Lcom/google/gwt/core/client/JavaScriptObject;)(param);
+                selfJ.@com.smartgwt.client.core.DataClass::fireEvent(Lcom/google/gwt/event/shared/GwtEvent;)(event);
+            });
+   }-*/;
 
     // ********************* Static Methods ***********************
         
@@ -309,6 +497,38 @@ public class Tab extends RefDataClass {
         }
     }
 
+    /**
+     * If specified, this tab will show an icon next to the tab title.  Note that as with  {@link
+     * com.smartgwt.client.widgets.Button#getIcon icon}, the URL of a tabs icon will be updated to reflect disabled state.<br>
+     * If desired a click handler may be assigned to the icon, which will be fired when the user clicks the tab. This method
+     * takes a single parameter <code>tab</code>, a pointer to the tab object.
+     *
+     * @param icon icon Default value is null
+     * @param iconWidth the icon width
+     * @param iconHeight the icon height
+     * @see <a href="http://www.smartclient.com/smartgwt/showcase/#layout_tabs_orientation" target="examples">Orientation Example</a>
+     */
+    public void setIcon(String icon, int iconWidth, int iconHeight) {
+        setIcon(icon);
+        setIconWidth(iconWidth);
+        setIconHeight(iconHeight);
+    }
+
+    /**
+     * If specified, this tab will show an icon next to the tab title.  Note that as with  {@link
+     * com.smartgwt.client.widgets.Button#getIcon icon}, the URL of a tabs icon will be updated to reflect disabled state.<br>
+     * If desired a click handler may be assigned to the icon, which will be fired when the user clicks the tab. This method
+     * takes a single parameter <code>tab</code>, a pointer to the tab object.
+     *
+     * @param icon icon Default value is null
+     * @param iconSize the icon size
+     * @see <a href="http://www.smartclient.com/smartgwt/showcase/#layout_tabs_orientation" target="examples">Orientation Example</a>
+     */
+    public void setIcon(String icon, int iconSize) {
+        setIcon(icon);
+        setIconSize(iconSize);
+    }
+
     /**
      * If specified, this tab will show an icon next to the tab title.  Note that as with  {@link
      * com.smartgwt.client.widgets.Button#getIcon icon}, the URL of a tabs icon will be updated to reflect disabled state.<br>
@@ -354,15 +574,6 @@ public class Tab extends RefDataClass {
         return Canvas.getOrCreateRef(getAttributeAsJavaScriptObject("pane"));
     }
 
-    /**
-    * Size in pixels of the icon for closing tabs, displayed when {@link com.smartgwt.client.widgets.tab.TabSet#getCanCloseTabs canCloseTabs} is true.
-    *
-    * @param closeIconSize closeIconSize Default value is 16
-    */
-    public void setCloseIconSize(int closeIconSize) {
-        setAttribute("closeIconSize", closeIconSize);
-    }
-
     /**
      * Context menu to show for this tab.
      *
@@ -397,7 +608,6 @@ public class Tab extends RefDataClass {
     }
 
     private static TabSet getTabSet(JavaScriptObject jsObj) {
-        if(jsObj == null) return null;
         Object ref = JSOHelper.getAttributeAsObject((JavaScriptObject) jsObj, SC.REF);
         if(ref instanceof Tab) {
             return ((Tab) ref).getTabSet();
