@@ -1,6 +1,7 @@
 package org.inria.bmajwatcher.client;
 
 import org.inria.bmajwatcher.client.ui.HomePage;
+import org.inria.bmajwatcher.client.ui.confirmation.MessagePanel;
 import org.inria.bmajwatcher.client.ui.styles.Resources;
 
 import com.google.gwt.core.client.EntryPoint;
@@ -26,6 +27,7 @@ public class BmajWatcher implements EntryPoint {
 			
 			@Override
 			public void run() {
+				RootPanel.get().add(MessagePanel.getInstance());
 				RootPanel.get().add(new HomePage());
 			}
 		};
