@@ -15,6 +15,9 @@ public interface BankDetailServiceAsync {
 	void getFields(boolean restricted,
 			AsyncCallback<Map<String, List<String>>> callback);
 
-	void getTypes(AsyncCallback<List<String>> callback);
+	void getTypes(String login, AsyncCallback<List<String>> callback);
+
+	void getDependencies(String bankName,
+			AsyncCallback<Map<String, String>> callback);
 
 }
