@@ -35,7 +35,8 @@ public interface BankRemovalService extends RemoteService {
 	 * Remove the all the production directories and stored sessions from db.
 	 * 
 	 * @param bankName
+	 * @param noHistory whether to delete all bank history from db
 	 * @param keepProd whether to delete the production directories
 	 */
-	public void deleteBank(String bankName, boolean keepProd);
+	public void deleteBank(String bankName, boolean noHistory, boolean keepProd);
 }
