@@ -11,7 +11,7 @@ public interface BankRemovalServiceAsync {
 	
 	void getDirectories(String bankName, AsyncCallback<List<String>> callback);
 
-	void deleteBank(String bankName, boolean keepProd, AsyncCallback<Void> callback);
+	void deleteBank(String bankName, boolean noHistory, boolean keepProd, AsyncCallback<Void> callback);
 
 	void deleteDirectories(List<String> versions, String bankName,
 			boolean keepProd, AsyncCallback<Void> callback);
