@@ -20,13 +20,14 @@ public interface BankStatService extends RemoteService {
 	public Map<String, Integer> banksStatus();
 	
 	/**
-	 * Returns a list of objects that contain information about a given
-	 * bank across its updates.
+	 * Returns list of stats for each update of a given bank up
+	 * to max updates.
 	 * 
 	 * @param bankName
+	 * @param max if <= 0, return all updates
 	 * @return
 	 */
-	public List<Map<String, String>> getBankStats(String bankName);
+	public List<Map<String, String>> getBankStats(String bankName, int max);
 	
 	/**
 	 * Returns info about all the online banks.
@@ -35,7 +36,9 @@ public interface BankStatService extends RemoteService {
 	 * 	- name of the bank
 	 * 	- server from where the bank was downloaded
 	 * 	- type of the bank
+	 * 
+	 * @param userkey that identifies the user whose group is be considered
 	 * @return
 	 */
-	public List<Map<String, String>> getBanksInfo();
+	public List<Map<String, String>> getBanksInfo(String userKey);
 }
