@@ -13,6 +13,7 @@ import org.inria.bmajwatcher.client.services.BankDetailServiceAsync;
 import org.inria.bmajwatcher.client.services.BankRemovalServiceAsync;
 import org.inria.bmajwatcher.client.services.BankStatServiceAsync;
 import org.inria.bmajwatcher.client.services.BiomajLauncherServiceAsync;
+import org.inria.bmajwatcher.client.services.MaintenanceServiceAsync;
 import org.inria.bmajwatcher.client.services.UserManagerServiceAsync;
 import org.inria.bmajwatcher.client.ui.bank_editor.BankEditorDialog;
 import org.inria.bmajwatcher.client.ui.confirmation.MessagePanel;
@@ -136,6 +137,9 @@ public class HomePage extends Composite implements com.google.gwt.event.dom.clie
 	private String loggedUser = null;
 	private boolean isAdmin = false;
 	
+	private ToolStripButton maintenance;
+	private boolean isMaintenance = false;
+	
 	private ListGrid grid;
 	private MainCss css = Resources.INSTANCE.mainCss();
 	
@@ -495,8 +499,53 @@ public class HomePage extends Composite implements com.google.gwt.event.dom.clie
 				}
 			});
 			ts.addButton(bankEditor);
-			ts.addSeparator();
+			ts.addSeparator();		
+			
 			ts.addButton(typeHierarchy);
+			
+			
+			maintenance = new ToolStripButton();
+			maintenance.setIcon("maintenance-off.png");
+			maintenance.setTitle("Maintenance mode");
+			if(!isAdmin) {
+				maintenance.disable();
+			}
+			MaintenanceServiceAsync.INSTANCE.getMaintenanceMode(new AsyncCallback<Boolean>() {			
+				
+				@Override
+				public void onSuccess(Boolean mode) {
+					isMaintenance = mode;
+					if(isMaintenance) {
+						maintenance.setIcon("maintenance-on.png");
+					}
+					else {
+						maintenance.setIcon("maintenance-off.png");
+					}
+				}
+				
+				@Override
+				public void onFailure(Throwable caught) {
+					SC.warn("Maintenance access : RPC failure");
+				}
+			});
+			
+			maintenance.addClickHandler(new com.smartgwt.client.widgets.events.ClickHandler() {
+				
+				@Override
+				public void onClick(com.smartgwt.client.widgets.events.ClickEvent event) {
+					//TODO call server to update status
+					if(isMaintenance) {
+						setMaintenanceMode(false);
+					}
+					else {
+						setMaintenanceMode(true);
+					}
+						
+				}
+			});
+			ts.addButton(maintenance);
+			
+			
 		} else {
 			ts.addButton(detailIcon);
 			ts.addSeparator();
@@ -508,6 +557,27 @@ public class HomePage extends Composite implements com.google.gwt.event.dom.clie
 	}
 	
 	
+	private void setMaintenanceMode(boolean mode) {
+		isMaintenance = mode;
+		if(isMaintenance) {
+			maintenance.setIcon("maintenance-on.png");
+		}
+		else {
+			maintenance.setIcon("maintenance-off.png");
+		}
+		MaintenanceServiceAsync.INSTANCE.setMaintenanceMode(mode,new AsyncCallback<Void>() {			
+			
+			@Override
+			public void onSuccess(Void result) {
+			}
+			
+			@Override
+			public void onFailure(Throwable caught) {
+				SC.warn("Maintenance access : RPC failure");
+			}
+		});
+	}
+	
 	private void generateStatsMenu(List<Map<String, String>> data) {
 		
 		VerticalPanel topMenu = new VerticalPanel();
@@ -1471,6 +1541,10 @@ public class HomePage extends Composite implements com.google.gwt.event.dom.clie
 	}
 
 	private void updateBank(String bankName) {
+		if(isMaintenance && !isAdmin) {
+			MessagePanel.showMessage("Server in maintenance, no update allowed");
+			return;
+		}
 		BiomajLauncherServiceAsync.INSTANCE.startUpdate(bankName, new AsyncCallback<Boolean>() {
 			
 			@Override
@@ -1490,6 +1564,10 @@ public class HomePage extends Composite implements com.google.gwt.event.dom.clie
 	}
 	
 	private void rebuildBank(String bankName) {
+		if(isMaintenance && !isAdmin) {
+			MessagePanel.showMessage("Server in maintenance, no update allowed");
+			return;
+		}
 		BiomajLauncherServiceAsync.INSTANCE.rebuild(bankName, new AsyncCallback<Boolean>() {
 			
 			@Override
@@ -1509,6 +1587,10 @@ public class HomePage extends Composite implements com.google.gwt.event.dom.clie
 	}
 	
 	private void updateBankNew(String bankName) {
+		if(isMaintenance && !isAdmin) {
+			MessagePanel.showMessage("Server in maintenance, no update allowed");
+			return;
+		}
 		BiomajLauncherServiceAsync.INSTANCE.startUpdateNew(bankName, new AsyncCallback<Boolean>() {
 					
 			@Override
@@ -1528,6 +1610,10 @@ public class HomePage extends Composite implements com.google.gwt.event.dom.clie
 	}
 	
 	private void updateBankFromScratch(String bankName) {
+		if(isMaintenance && !isAdmin) {
+			MessagePanel.showMessage("Server in maintenance, no update allowed");
+			return;
+		}
 		BiomajLauncherServiceAsync.INSTANCE.startUpdateFromScratch(bankName, new AsyncCallback<Boolean>() {
 			
 			@Override
