@@ -1,7 +1,6 @@
 package org.inria.bmajwatcher.client.ui.bank_editor;
 
 
-
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.HashMap;
@@ -31,6 +30,7 @@ import com.google.gwt.user.client.rpc.AsyncCallback;
 import com.google.gwt.user.client.ui.AbsolutePanel;
 import com.google.gwt.user.client.ui.Anchor;
 import com.google.gwt.user.client.ui.Button;
+import com.google.gwt.user.client.ui.CheckBox;
 import com.google.gwt.user.client.ui.ComplexPanel;
 import com.google.gwt.user.client.ui.DialogBox;
 import com.google.gwt.user.client.ui.HasHorizontalAlignment;
@@ -214,6 +214,7 @@ public class ProcessEditor extends VerticalPanel {
 							this.processes.put(PREFIX + process + ".args", content.get(process + ".args"));
 							this.processes.put(PREFIX + process + ".type", content.get(process + ".type"));
 							this.processes.put(PREFIX + process + ".desc", content.get(process + ".desc"));
+							this.processes.put(PREFIX + process + ".cluster", content.get(process + ".cluster"));
 							
 							ComplexPanel processPnl = getProcessPanel(metaContent, process);
 							metaContent.add(processPnl);
@@ -540,6 +541,7 @@ public class ProcessEditor extends VerticalPanel {
 		String args = "";
 		String desc = "";
 		String type = "";
+		boolean cluster = false;
 		
 		if (processes.get(PREFIX + keyName + ".name") != null)
 			name = processes.get(PREFIX + keyName + ".name");
@@ -551,6 +553,8 @@ public class ProcessEditor extends VerticalPanel {
 			desc = processes.get(PREFIX + keyName + ".desc");
 		if (processes.get(PREFIX + keyName + ".type") != null)
 			type = processes.get(PREFIX + keyName + ".type");
+		if (processes.get(PREFIX + keyName + ".cluster") != null)
+			cluster = processes.get(PREFIX + keyName + ".cluster").equals("true");
 
 		
 		final DialogBox dialog = new DialogBox(false, true);
@@ -598,6 +602,11 @@ public class ProcessEditor extends VerticalPanel {
 		Label lblType = new Label("Type :");
 		lblType.setWidth("150px");
 		
+		Label lblCluster = new Label("Execute on cluster :");
+		lblCluster.setWidth("150px");
+		final CheckBox cbCluster = new CheckBox();
+		cbCluster.setValue(cluster);
+		
 		HorizontalPanel hpKey = new HorizontalPanel();
 		hpKey.add(lblKey);
 		hpKey.add(txtKey);
@@ -609,7 +618,7 @@ public class ProcessEditor extends VerticalPanel {
 		HorizontalPanel hpExe = new HorizontalPanel();
 		hpExe.add(lblExe);
 		
-		ProcessSuggestOracle oracle = new ProcessSuggestOracle(availablePs);
+		MySuggestOracle oracle = new MySuggestOracle(availablePs);
 		final SuggestBox suggExe = new SuggestBox(oracle);
 		suggExe.setText(exe);
 		suggExe.addStyleName(css.suggestBox());
@@ -661,6 +670,11 @@ public class ProcessEditor extends VerticalPanel {
 		hpType.add(lblType);
 		hpType.add(txtType);
 		
+		HorizontalPanel hpCluster = new HorizontalPanel();
+		hpCluster.add(lblCluster);
+		hpCluster.add(cbCluster);
+		
+		
 		Button ok = new Button("Ok");
 		ok.addClickHandler(new ClickHandler() {
 			
@@ -697,13 +711,15 @@ public class ProcessEditor extends VerticalPanel {
 						processes.remove(PREFIX + keyName + ".args");
 						processes.remove(PREFIX + keyName + ".desc");
 						processes.remove(PREFIX + keyName + ".type");
-						
+						processes.remove(PREFIX + keyName + ".cluster");
 					}
 					processes.put(PREFIX + newKeyName + ".name", txtName.getText());
 					processes.put(PREFIX + newKeyName + ".exe", suggExe.getText());
 					processes.put(PREFIX + newKeyName + ".args", txtArgs.getText());
 					processes.put(PREFIX + newKeyName + ".desc", txtDesc.getText());
 					processes.put(PREFIX + newKeyName + ".type", txtType.getText());
+					processes.put(PREFIX + newKeyName + ".cluster", String.valueOf(cbCluster.getValue()));
+					
 					dialog.hide();
 				}
 			}
@@ -727,6 +743,7 @@ public class ProcessEditor extends VerticalPanel {
 		content.add(hpArgs);
 		content.add(hpDesc);
 		content.add(hpType);
+		content.add(hpCluster);
 		
 		dialog.setWidget(main);
 		dialog.setHTML("<b>Process edition</b>");
