@@ -2,7 +2,6 @@ package org.inria.bmajwatcher.client.ui.styles;
 
 import com.google.gwt.core.client.GWT;
 import com.google.gwt.resources.client.ClientBundle;
-import com.google.gwt.resources.client.ImageResource;
 
 public interface Resources extends ClientBundle {
 
@@ -10,7 +9,5 @@ public interface Resources extends ClientBundle {
 	
 	@Source("main.css")
 	public MainCss mainCss();
-	
-	@Source("logo.gif")
-	ImageResource logo();
+
 }
