@@ -34,8 +34,8 @@ public class BankRemovalServiceImpl extends RemoteServiceServlet implements Bank
 
 
 	@Override
-	public void deleteBank(String bankName, boolean keepProd) {
-		new BiomajLauncherServiceImpl().removeAll(bankName, keepProd);
+	public void deleteBank(String bankName, boolean noHistory, boolean keepProd) {
+		new BiomajLauncherServiceImpl().removeAll(bankName, noHistory, keepProd);
 		
 	}
 
