@@ -35,13 +35,13 @@ public class BankStatServiceImpl extends RemoteServiceServlet implements BankSta
 	}
 
 	@Override
-	public List<Map<String, String>> getBankStats(String bankName) {
-		return StatsRetriever.getBankStats(bankName);
+	public List<Map<String, String>> getBankStats(String bankName, int max) {
+		return StatsRetriever.getBankStats(bankName, max);
 	}
 
 	@Override
-	public List<Map<String, String>> getBanksInfo() {
-		return StatsRetriever.getBanksSize();
+	public List<Map<String, String>> getBanksInfo(String userKey) {
+		return StatsRetriever.getBanksSize(userKey);
 	}
 
 }
