@@ -19,20 +19,21 @@ public class ErrorListingService extends HttpServlet {
 	protected void doPost(HttpServletRequest req, HttpServletResponse resp)
 			throws ServletException, IOException {
 
-		fetchData(resp.getWriter());
+		fetchData(resp.getWriter(), req.getParameter("auth_key"));
 	}
 	
 	@Override
 	protected void doGet(HttpServletRequest req, HttpServletResponse resp)
 			throws ServletException, IOException {
-
-		fetchData(resp.getWriter());
+		fetchData(resp.getWriter(), req.getParameter("auth_key"));
 	}
 	
-	private void fetchData(PrintWriter out) {
-		String maxMessages = getServletContext().getInitParameter("MESSAGE_MAX");
-		out.write(ErrorRetriever.getMessages(maxMessages));
-		out.flush();
+	private void fetchData(PrintWriter out, String userKey) {
+		if (userKey != null && !userKey.trim().isEmpty()) {
+			String maxMessages = getServletContext().getInitParameter("MESSAGE_MAX");
+			out.write(ErrorRetriever.getMessages(maxMessages, userKey));
+			out.flush();
+		}
 	}
 	
 }
