@@ -54,10 +54,11 @@ public interface Launcher {
 	 * biomaj.sh --remove bankName --all
 	 * 
 	 * @param bankName
+	 * @param noHistory whether to keep bank history on db
 	 * @param keepProd whether to delete or not the production directories
 	 * @return
 	 */
-	public boolean removeAll(String bankName, boolean keepPord);
+	public boolean removeAll(String bankName, boolean noHistory, boolean keepPord);
 	
 	/**
 	 * Remove specified production directories from bank.
